Documentation
¶
Index ¶
- type Handler
- type Sender
- func (_m *Sender) ClaimIdentity(ctx context.Context, def *core.IdentityClaim, signingIdentity *core.SignerRef, ...) error
- func (_m *Sender) DefineContractAPI(ctx context.Context, httpServerURL string, api *core.ContractAPI, ...) error
- func (_m *Sender) DefineDatatype(ctx context.Context, datatype *core.Datatype, waitConfirm bool) error
- func (_m *Sender) DefineFFI(ctx context.Context, ffi *fftypes.FFI, waitConfirm bool, topics []string) error
- func (_m *Sender) DefineTokenPool(ctx context.Context, pool *core.TokenPool, waitConfirm bool) error
- func (_m *Sender) Name() string
- func (_m *Sender) PublishContractAPI(ctx context.Context, httpServerURL string, name string, networkName string, ...) (*core.ContractAPI, error)
- func (_m *Sender) PublishFFI(ctx context.Context, name string, version string, networkName string, ...) (*fftypes.FFI, error)
- func (_m *Sender) PublishTokenPool(ctx context.Context, poolNameOrID string, networkName string, waitConfirm bool) (*core.TokenPool, error)
- func (_m *Sender) UpdateIdentity(ctx context.Context, identity *core.Identity, def *core.IdentityUpdate, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
Handler is an autogenerated mock type for the Handler type
func NewHandler ¶
NewHandler creates a new instance of Handler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Handler) HandleDefinitionBroadcast ¶
func (_m *Handler) HandleDefinitionBroadcast(ctx context.Context, state *core.BatchState, msg *core.Message, data core.DataArray, tx *fftypes.UUID) (definitions.HandlerResult, error)
HandleDefinitionBroadcast provides a mock function with given fields: ctx, state, msg, data, tx
type Sender ¶
Sender is an autogenerated mock type for the Sender type
func NewSender ¶
NewSender creates a new instance of Sender. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Sender) ClaimIdentity ¶
func (_m *Sender) ClaimIdentity(ctx context.Context, def *core.IdentityClaim, signingIdentity *core.SignerRef, parentSigner *core.SignerRef) error
ClaimIdentity provides a mock function with given fields: ctx, def, signingIdentity, parentSigner
func (*Sender) DefineContractAPI ¶
func (_m *Sender) DefineContractAPI(ctx context.Context, httpServerURL string, api *core.ContractAPI, waitConfirm bool, topics []string) error
DefineContractAPI provides a mock function with given fields: ctx, httpServerURL, api, waitConfirm, topics
func (*Sender) DefineDatatype ¶
func (_m *Sender) DefineDatatype(ctx context.Context, datatype *core.Datatype, waitConfirm bool) error
DefineDatatype provides a mock function with given fields: ctx, datatype, waitConfirm
func (*Sender) DefineFFI ¶
func (_m *Sender) DefineFFI(ctx context.Context, ffi *fftypes.FFI, waitConfirm bool, topics []string) error
DefineFFI provides a mock function with given fields: ctx, ffi, waitConfirm, topics
func (*Sender) DefineTokenPool ¶
func (_m *Sender) DefineTokenPool(ctx context.Context, pool *core.TokenPool, waitConfirm bool) error
DefineTokenPool provides a mock function with given fields: ctx, pool, waitConfirm
func (*Sender) PublishContractAPI ¶
func (_m *Sender) PublishContractAPI(ctx context.Context, httpServerURL string, name string, networkName string, waitConfirm bool, topics []string) (*core.ContractAPI, error)
PublishContractAPI provides a mock function with given fields: ctx, httpServerURL, name, networkName, waitConfirm, topics
func (*Sender) PublishFFI ¶
func (_m *Sender) PublishFFI(ctx context.Context, name string, version string, networkName string, waitConfirm bool, topics []string) (*fftypes.FFI, error)
PublishFFI provides a mock function with given fields: ctx, name, version, networkName, waitConfirm, topics
func (*Sender) PublishTokenPool ¶
func (_m *Sender) PublishTokenPool(ctx context.Context, poolNameOrID string, networkName string, waitConfirm bool) (*core.TokenPool, error)
PublishTokenPool provides a mock function with given fields: ctx, poolNameOrID, networkName, waitConfirm
func (*Sender) UpdateIdentity ¶
func (_m *Sender) UpdateIdentity(ctx context.Context, identity *core.Identity, def *core.IdentityUpdate, signingIdentity *core.SignerRef, waitConfirm bool) error
UpdateIdentity provides a mock function with given fields: ctx, identity, def, signingIdentity, waitConfirm